summaryrefslogtreecommitdiff
path: root/buildscripts
diff options
context:
space:
mode:
authorErnie Hershey <ernie.hershey@10gen.com>2014-09-02 11:45:36 -0400
committerErnie Hershey <ernie.hershey@10gen.com>2014-09-02 11:45:36 -0400
commit5181c39ebe970ef8053c70e7c283510d8ed2f41a (patch)
treec9e8fd573649eca83aaa736586defe44c554c00e /buildscripts
parentda2b649e755ba903e8b38ffb9cf24f3769bcb319 (diff)
downloadmongo-5181c39ebe970ef8053c70e7c283510d8ed2f41a.tar.gz
SERVER-14023 Add RHEL 7 Enterprise .rpm
Diffstat (limited to 'buildscripts')
-rwxr-xr-xbuildscripts/packager-enterprise.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/buildscripts/packager-enterprise.py b/buildscripts/packager-enterprise.py
index 29fec8caff5..925d3fcba03 100755
--- a/buildscripts/packager-enterprise.py
+++ b/buildscripts/packager-enterprise.py
@@ -191,11 +191,11 @@ class Distro(object):
raise Exception("BUG: unsupported platform?")
def build_os(self):
"""Return the build os label in the binary package to download ("rhel57" and "rhel62"
for redhat, "ubuntu1204" for Ubuntu and "debian71" for Debian)"""
if re.search("(redhat|fedora|centos)", self.n):
- return [ "rhel62", "rhel57" ]
+ return [ "rhel70", "rhel62", "rhel57" ]
elif self.n == 'ubuntu':
return [ "ubuntu1204" ]
elif self.n == 'debian':
@@ -191,11 +191,11 @@ class Distro(object):
raise Exception("BUG: unsupported platform?")
def build_os(self):
- """Return the build os label in the binary package to download ("rhel57" and "rhel62"
+ """Return the build os label in the binary package to download ("rhel57", "rhel62" and "rhel70"
for redhat, "ubuntu1204" for Ubuntu and "debian71" for Debian)"""
if re.search("(redhat|fedora|centos)", self.n):